Tools
=====

.. automodule:: metacells.tools

General Tools
+++++++++++++

.. automodule:: metacells.tools.apply
    :members:

.. automodule:: metacells.tools.convey
    :members:

Filtering the Data
++++++++++++++++++

.. automodule:: metacells.tools.filter
    :members:

.. automodule:: metacells.tools.mask
    :members:

.. automodule:: metacells.tools.properly_sampled
    :members:

.. automodule:: metacells.tools.named
    :members:

.. automodule:: metacells.tools.high
    :members:

.. automodule:: metacells.tools.bursty_lonely
    :members:

.. automodule:: metacells.tools.rare
    :members:

Building the Graph
++++++++++++++++++

.. automodule:: metacells.tools.downsample
    :members:

.. automodule:: metacells.tools.similarity
    :members:

.. automodule:: metacells.tools.knn_graph
    :members:

Computing the Metacells
+++++++++++++++++++++++

.. automodule:: metacells.tools.candidates
    :members:

.. automodule:: metacells.tools.deviants
    :members:

.. automodule:: metacells.tools.dissolve
    :members:

Evaluating the Metacells
++++++++++++++++++++++++

.. automodule:: metacells.tools.group
    :members:

.. automodule:: metacells.tools.quality
    :members:

.. automodule:: metacells.tools.distinct
    :members:

Visualizing the Metacells
+++++++++++++++++++++++++

.. automodule:: metacells.tools.layout
    :members:

Projecting onto Metacells
+++++++++++++++++++++++++

.. automodule:: metacells.tools.project
    :members:
